@@ -1,6 +1,5 @@
 # --
-# Kernel/Modules/AdminCustomerUserGroup.pm - to add/update/delete groups <-> users
-# Copyright (C) 2001-2013 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -15,9 +14,6 @@ use warnings;
 use Kernel::System::CustomerUser;
 use Kernel::System::CustomerGroup;
 
-use vars qw($VERSION);
-$VERSION = qw($Revision: 1.43 $) [1];
-
 sub new {
     my ( $Type, %Param ) = @_;
 
@@ -66,8 +62,7 @@ sub Run {
         # get user data
         my $ID = $Self->{ParamObject}->GetParam( Param => 'ID' );
         my %UserData = $Self->{CustomerUserObject}->CustomerUserDataGet( User => $ID );
-        my $CustomerName
-            = $Self->{CustomerUserObject}->CustomerName( UserLogin => $UserData{UserLogin} );
+        my $CustomerName = $Self->{CustomerUserObject}->CustomerName( UserLogin => $UserData{UserLogin} );
 
         # get group data
         my %GroupData = $Self->{GroupObject}->GroupList( Valid => 1 );
@@ -111,10 +106,10 @@ sub Run {
         my %GroupData = $Self->{GroupObject}->GroupGet( ID => $ID );
 
         # search customer user
-        my %CustomerUserList
-            = $Self->{CustomerUserObject}->CustomerSearch( Search => $Param{CustomerUserSearch}, );
-        my @CustomerUserKeyList
-            = sort { $CustomerUserList{$a} cmp $CustomerUserList{$b} } keys %CustomerUserList;
+        my %CustomerUserList = $Self->{CustomerUserObject}->CustomerSearch(
+            Search => $Param{CustomerUserSearch},
+        );
+        my @CustomerUserKeyList = sort { $CustomerUserList{$a} cmp $CustomerUserList{$b} } keys %CustomerUserList;
 
         # set max count
         my $MaxCount = @CustomerUserKeyList;
@@ -187,9 +182,13 @@ sub Run {
         }
 
         # get group data
-        my %UserData = $Self->{CustomerUserObject}->CustomerUserList( Valid => 1 );
+        my %UserData = $Self->{CustomerUserObject}->CustomerSearch(
+            Search => $Param{CustomerUserSearch},
+        );
+
         my %NewPermission;
         for my $UserID ( sort keys %UserData ) {
+
             for my $Permission ( sort keys %Permissions ) {
                 $NewPermission{$Permission} = 0;
                 my @Array = @{ $Permissions{$Permission} };
@@ -274,10 +273,10 @@ sub Run {
     $Output .= $Self->{LayoutObject}->NavigationBar();
 
     # search customer user
-    my %CustomerUserList
-        = $Self->{CustomerUserObject}->CustomerSearch( Search => $Param{CustomerUserSearch}, );
-    my @CustomerUserKeyList
-        = sort { $CustomerUserList{$a} cmp $CustomerUserList{$b} } keys %CustomerUserList;
+    my %CustomerUserList = $Self->{CustomerUserObject}->CustomerSearch(
+        Search => $Param{CustomerUserSearch},
+    );
+    my @CustomerUserKeyList = sort { $CustomerUserList{$a} cmp $CustomerUserList{$b} } keys %CustomerUserList;
 
     # count results
     my $CustomerUserCount = @CustomerUserKeyList;
@@ -307,8 +306,7 @@ sub Run {
             my $UserName = $Self->{CustomerUserObject}->CustomerName(
                 UserLogin => $CustomerUserKeyList[ $Counter - 1 ]
             );
-            $UserRowParam{ $User{UserID} }
-                = "$UserName <$User{UserEmail}> ($User{UserCustomerID})";
+            $UserRowParam{ $User{UserID} } = "$UserName <$User{UserEmail}> ($User{UserCustomerID})";
         }
     }
 
@@ -334,7 +332,10 @@ sub _Change {
     my %Data        = %{ $Param{Data} };
     my $Type        = $Param{Type} || 'CustomerUser';
     my $NeType      = $Type eq 'Group' ? 'CustomerUser' : 'Group';
-    my %VisibleType = ( CustomerUser => 'Customer', Group => 'Group', );
+    my %VisibleType = (
+        CustomerUser => 'Customer',
+        Group        => 'Group',
+    );
     my $SearchLimit = $Param{SearchLimit};
 
     my @ItemList = ();
@@ -393,8 +394,9 @@ sub _Change {
         Name => "ChangeHeading$VisibleType{$NeType}",
     );
 
+    TYPE:
     for my $Type ( @{ $Self->{ConfigObject}->Get('System::Customer::Permission') } ) {
-        next if !$Type;
+        next TYPE if !$Type;
         my $Mark = $Type eq 'rw' ? "Highlight" : '';
         $Self->{LayoutObject}->Block(
             Name => 'ChangeHeader',
@@ -412,7 +414,9 @@ sub _Change {
         if ( !@ItemList ) {
             $Self->{LayoutObject}->Block(
                 Name => 'ChangeItemCountLimit',
-                Data => { ItemCount => 0, },
+                Data => {
+                    ItemCount => 0,
+                },
             );
 
             my $ColSpan = "3";
@@ -428,13 +432,17 @@ sub _Change {
         elsif ( @ItemList > $SearchLimit ) {
             $Self->{LayoutObject}->Block(
                 Name => 'ChangeItemCountLimit',
-                Data => { ItemCount => ">" . $SearchLimit, },
+                Data => {
+                    ItemCount => ">" . $SearchLimit,
+                },
             );
         }
         else {
             $Self->{LayoutObject}->Block(
                 Name => 'ChangeItemCount',
-                Data => { ItemCount => scalar @ItemList, },
+                Data => {
+                    ItemCount => scalar @ItemList,
+                },
             );
         }
     }
@@ -457,8 +465,9 @@ sub _Change {
             },
         );
 
+        TYPE:
         for my $Type ( @{ $Self->{ConfigObject}->Get('System::Customer::Permission') } ) {
-            next if !$Type;
+            next TYPE if !$Type;
             my $Mark     = $Type eq 'rw'        ? "Highlight"          : '';
             my $Selected = $Param{$Type}->{$ID} ? ' checked="checked"' : '';
             $Self->{LayoutObject}->Block(
@@ -522,7 +531,9 @@ sub _Overview {
     $Self->{LayoutObject}->Block( Name => 'AlwaysGroupsConfig' );
 
     # output filter and default block
-    $Self->{LayoutObject}->Block( Name => 'Filter', );
+    $Self->{LayoutObject}->Block(
+        Name => 'Filter',
+    );
 
     # output result block
     $Self->{LayoutObject}->Block(
@@ -536,7 +547,9 @@ sub _Overview {
     if ( !@CustomerUserKeyList ) {
         $Self->{LayoutObject}->Block(
             Name => 'ResultCustomerUserCountLimit',
-            Data => { CustomerUserCount => 0, },
+            Data => {
+                CustomerUserCount => 0,
+            },
         );
         $Self->{LayoutObject}->Block(
             Name => 'NoDataFoundMsgList',
@@ -545,13 +558,17 @@ sub _Overview {
     elsif ( @CustomerUserKeyList > $SearchLimit ) {
         $Self->{LayoutObject}->Block(
             Name => 'ResultCustomerUserCountLimit',
-            Data => { CustomerUserCount => ">" . $SearchLimit, },
+            Data => {
+                CustomerUserCount => ">" . $SearchLimit,
+            },
         );
     }
     else {
         $Self->{LayoutObject}->Block(
             Name => 'ResultCustomerUserCount',
-            Data => { CustomerUserCount => scalar @CustomerUserKeyList, },
+            Data => {
+                CustomerUserCount => scalar @CustomerUserKeyList,
+            },
         );
     }
 
