@@ -1,5 +1,5 @@
 # --
-# Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -666,6 +666,7 @@ sub Run {
                     # get ticket data instead
                     %Data = $Self->{TicketObject}->TicketGet(
                         TicketID      => $TicketID,
+                        Extended      => 1,
                         DynamicFields => 1,
                     );
 
@@ -841,6 +842,7 @@ sub Run {
                 # get first article data
                 my %Data = $Self->{TicketObject}->ArticleFirstArticle(
                     TicketID      => $TicketID,
+                    Extended      => 1,
                     DynamicFields => 1,
                 );
 
@@ -849,6 +851,7 @@ sub Run {
                     # get ticket data instead
                     %Data = $Self->{TicketObject}->TicketGet(
                         TicketID      => $TicketID,
+                        Extended      => 1,
                         DynamicFields => 1,
                     );
 
@@ -1891,11 +1894,13 @@ sub Run {
             Prefix   => 'ArticleCreateTimeStart',
             Format   => 'DateInputFormat',
             DiffTime => -( ( 60 * 60 * 24 ) * 30 ),
+            Validate => 1,
         );
         $Param{ArticleCreateTimeStop} = $Self->{LayoutObject}->BuildDateSelection(
             %GetParam,
-            Prefix => 'ArticleCreateTimeStop',
-            Format => 'DateInputFormat',
+            Prefix   => 'ArticleCreateTimeStop',
+            Format   => 'DateInputFormat',
+            Validate => 1,
         );
         $Param{TicketCreateTimePoint} = $Self->{LayoutObject}->BuildSelection(
             Data       => [ 1 .. 59 ],
@@ -1927,11 +1932,13 @@ sub Run {
             Prefix   => 'TicketCreateTimeStart',
             Format   => 'DateInputFormat',
             DiffTime => -( ( 60 * 60 * 24 ) * 30 ),
+            Validate => 1,
         );
         $Param{TicketCreateTimeStop} = $Self->{LayoutObject}->BuildDateSelection(
             %GetParam,
-            Prefix => 'TicketCreateTimeStop',
-            Format => 'DateInputFormat',
+            Prefix   => 'TicketCreateTimeStop',
+            Format   => 'DateInputFormat',
+            Validate => 1,
         );
 
         $Param{TicketChangeTimePoint} = $Self->{LayoutObject}->BuildSelection(
@@ -1964,11 +1971,13 @@ sub Run {
             Prefix   => 'TicketChangeTimeStart',
             Format   => 'DateInputFormat',
             DiffTime => -( ( 60 * 60 * 24 ) * 30 ),
+            Validate => 1,
         );
         $Param{TicketChangeTimeStop} = $Self->{LayoutObject}->BuildDateSelection(
             %GetParam,
-            Prefix => 'TicketChangeTimeStop',
-            Format => 'DateInputFormat',
+            Prefix   => 'TicketChangeTimeStop',
+            Format   => 'DateInputFormat',
+            Validate => 1,
         );
 
         $Param{TicketCloseTimePoint} = $Self->{LayoutObject}->BuildSelection(
@@ -2001,11 +2010,13 @@ sub Run {
             Prefix   => 'TicketCloseTimeStart',
             Format   => 'DateInputFormat',
             DiffTime => -( ( 60 * 60 * 24 ) * 30 ),
+            Validate => 1,
         );
         $Param{TicketCloseTimeStop} = $Self->{LayoutObject}->BuildDateSelection(
             %GetParam,
-            Prefix => 'TicketCloseTimeStop',
-            Format => 'DateInputFormat',
+            Prefix   => 'TicketCloseTimeStop',
+            Format   => 'DateInputFormat',
+            Validate => 1,
         );
 
         $Param{TicketLastChangeTimePoint} = $Self->{LayoutObject}->BuildSelection(
@@ -2038,11 +2049,13 @@ sub Run {
             Prefix   => 'TicketLastChangeTimeStart',
             Format   => 'DateInputFormat',
             DiffTime => -( ( 60 * 60 * 24 ) * 30 ),
+            Validate => 1,
         );
         $Param{TicketLastChangeTimeStop} = $Self->{LayoutObject}->BuildDateSelection(
             %GetParam,
-            Prefix => 'TicketLastChangeTimeStop',
-            Format => 'DateInputFormat',
+            Prefix   => 'TicketLastChangeTimeStop',
+            Format   => 'DateInputFormat',
+            Validate => 1,
         );
 
         $Param{TicketEscalationTimePoint} = $Self->{LayoutObject}->BuildSelection(
@@ -2076,11 +2089,13 @@ sub Run {
             Prefix   => 'TicketEscalationTimeStart',
             Format   => 'DateInputFormat',
             DiffTime => -( ( 60 * 60 * 24 ) * 30 ),
+            Validate => 1,
         );
         $Param{TicketEscalationTimeStop} = $Self->{LayoutObject}->BuildDateSelection(
             %GetParam,
-            Prefix => 'TicketEscalationTimeStop',
-            Format => 'DateInputFormat',
+            Prefix   => 'TicketEscalationTimeStop',
+            Format   => 'DateInputFormat',
+            Validate => 1,
         );
 
         my %GetParamBackup = %GetParam;
