@@ -1,6 +1,5 @@
 # --
-# Kernel/System/ProcessManagement/TransitionAction/TicketSLASet.pm - A Module to set the ticket service
-# Copyright (C) 2001-2013 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -11,10 +10,17 @@ package Kernel::System::ProcessManagement::TransitionAction::TicketSLASet;
 
 use strict;
 use warnings;
+use utf8;
+
 use Kernel::System::VariableCheck qw(:all);
 
-use utf8;
-use Kernel::System::SLA;
+use base qw(Kernel::System::ProcessManagement::TransitionAction::Base);
+
+our @ObjectDependencies = (
+    'Kernel::System::Log',
+    'Kernel::System::SLA',
+    'Kernel::System::Ticket',
+);
 
 =head1 NAME
 
@@ -32,57 +38,11 @@ All TicketSLASet functions.
 
 =item new()
 
-create an object
+create an object. Do not use it directly, instead use:
 
-    use Kernel::Config;
-    use Kernel::System::Encode;
-    use Kernel::System::Log;
-    use Kernel::System::Time;
-    use Kernel::System::Main;
-    use Kernel::System::DB;
-    use Kernel::System::Ticket;
-    use Kernel::System::ProcessManagement::TransitionAction::TicketSLASet;
-
-    my $ConfigObject = Kernel::Config->new();
-    my $EncodeObject = Kernel::System::Encode->new(
-        ConfigObject => $ConfigObject,
-    );
-    my $LogObject = Kernel::System::Log->new(
-        ConfigObject => $ConfigObject,
-        EncodeObject => $EncodeObject,
-    );
-    my $TimeObject = Kernel::System::Time->new(
-        ConfigObject => $ConfigObject,
-        LogObject    => $LogObject,
-    );
-    my $MainObject = Kernel::System::Main->new(
-        ConfigObject => $ConfigObject,
-        EncodeObject => $EncodeObject,
-        LogObject    => $LogObject,
-    );
-    my $DBObject = Kernel::System::DB->new(
-        ConfigObject => $ConfigObject,
-        EncodeObject => $EncodeObject,
-        LogObject    => $LogObject,
-        MainObject   => $MainObject,
-    );
-    my $TicketObject = Kernel::System::Ticket->new(
-        ConfigObject       => $ConfigObject,
-        LogObject          => $LogObject,
-        DBObject           => $DBObject,
-        MainObject         => $MainObject,
-        TimeObject         => $TimeObject,
-        EncodeObject       => $EncodeObject,
-    );
-    my $TicketSLASetActionObject = Kernel::System::ProcessManagement::TransitionAction::TicketSLASet->new(
-        ConfigObject       => $ConfigObject,
-        LogObject          => $LogObject,
-        EncodeObject       => $EncodeObject,
-        DBObject           => $DBObject,
-        MainObject         => $MainObject,
-        TimeObject         => $TimeObject,
-        TicketObject       => $TicketObject,
-    );
+    use Kernel::System::ObjectManager;
+    local $Kernel::OM = Kernel::System::ObjectManager->new();
+    my $TicketSLASetObject = $Kernel::OM->Get('Kernel::System::ProcessManagement::TransitionAction::TicketSLASet');
 
 =cut
 
@@ -93,23 +53,6 @@ sub new {
     my $Self = {};
     bless( $Self, $Type );
 
-    # get needed objects
-    for my $Needed (
-        qw(ConfigObject LogObject EncodeObject DBObject MainObject TimeObject TicketObject)
-        )
-    {
-        die "Got no $Needed!" if !$Param{$Needed};
-
-        $Self->{$Needed} = $Param{$Needed};
-    }
-
-    $Self->{SLAObject} = Kernel::System::SLA->new(
-        %Param,
-        DBObject   => $Self->{DBObject},
-        MainObject => $Self->{MainObject},
-        TimeObject => $Self->{TimeObject},
-    );
-
     return $Self;
 }
 
@@ -120,10 +63,10 @@ sub new {
     my $TicketSLASetResult = $TicketSLASetActionObject->Run(
         UserID                   => 123,
         Ticket                   => \%Ticket,   # required
-        ProcessEntityID          => 'P123',     # optional
-        ActivityEntityID         => 'A123',     # optional
-        TransitionEntityID       => 'T123',     # optional
-        TransitionActionEntityID => 'TA123',    # optional
+        ProcessEntityID          => 'P123',
+        ActivityEntityID         => 'A123',
+        TransitionEntityID       => 'T123',
+        TransitionActionEntityID => 'TA123',
         Config                   => {
             SLA => 'MySLA',
             # or
@@ -142,67 +85,26 @@ sub new {
 sub Run {
     my ( $Self, %Param ) = @_;
 
-    for my $Needed (qw(UserID Ticket Config)) {
-        if ( !defined $Param{$Needed} ) {
-            $Self->{LogObject}->Log(
-                Priority => 'error',
-                Message  => "Need $Needed!",
-            );
-            return;
-        }
-    }
-
     # define a common message to output in case of any error
-    my $CommonMessage;
-    if ( $Param{ProcessEntityID} ) {
-        $CommonMessage .= "Process: $Param{ProcessEntityID}";
-    }
-    if ( $Param{ActivityEntityID} ) {
-        $CommonMessage .= " Activity: $Param{ActivityEntityID}";
-    }
-    if ( $Param{TransitionEntityID} ) {
-        $CommonMessage .= " Transition: $Param{TransitionEntityID}";
-    }
-    if ( $Param{TransitionActionEntityID} ) {
-        $CommonMessage .= " TransitionAction: $Param{TransitionActionEntityID}";
-    }
-    if ($CommonMessage) {
+    my $CommonMessage = "Process: $Param{ProcessEntityID} Activity: $Param{ActivityEntityID}"
+        . " Transition: $Param{TransitionEntityID}"
+        . " TransitionAction: $Param{TransitionActionEntityID} - ";
 
-        # add a separator
-        $CommonMessage .= " - ";
-    }
-    else{
-
-        # otherwise at least define it to prevent errors
-        $CommonMessage = '';
-    }
-
-    # Check if we have Ticket to deal with
-    if ( !IsHashRefWithData( $Param{Ticket} ) ) {
-        $Self->{LogObject}->Log(
-            Priority => 'error',
-            Message  => $CommonMessage . "Ticket has no values!",
-        );
-        return;
-    }
-
-    # Check if we have a ConfigHash
-    if ( !IsHashRefWithData( $Param{Config} ) ) {
-        $Self->{LogObject}->Log(
-            Priority => 'error',
-            Message  => $CommonMessage . "Config has no values!",
-        );
-        return;
-    }
+    # check for missing or wrong params
+    my $Success = $Self->_CheckParams(
+        %Param,
+        CommonMessage => $CommonMessage,
+    );
+    return if !$Success;
 
     # override UserID if specified as a parameter in the TA config
-    if ( IsNumber( $Param{Config}->{UserID} ) ) {
-        $Param{UserID} = $Param{Config}->{UserID};
-        delete $Param{Config}->{UserID};
-    }
+    $Param{UserID} = $Self->_OverrideUserID(%Param);
+
+    # use ticket attributes if needed
+    $Self->_ReplaceTicketAttributes(%Param);
 
     if ( !$Param{Config}->{SLAID} && !$Param{Config}->{SLA} ) {
-        $Self->{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'error',
             Message  => $CommonMessage . "No SLA or SLAID configured!",
         );
@@ -210,14 +112,14 @@ sub Run {
     }
 
     if ( !$Param{Ticket}->{ServiceID} && !$Param{Ticket}->{Service} ) {
-        $Self->{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'error',
             Message  => $CommonMessage . "To set a SLA the ticket requires a service!",
         );
         return;
     }
 
-    my $Success;
+    $Success = 0;
 
     # If Ticket's SLAID is already the same as the Value we
     # should set it to, we got nothing to do and return success
@@ -249,7 +151,7 @@ sub Run {
         );
 
         if ( !$Success ) {
-            $Self->{LogObject}->Log(
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'error',
                 Message  => $CommonMessage
                     . 'SLAID '
@@ -261,14 +163,14 @@ sub Run {
         }
 
         # set ticket SLA
-        $Success = $Self->{TicketObject}->TicketSLASet(
+        $Success = $Kernel::OM->Get('Kernel::System::Ticket')->TicketSLASet(
             TicketID => $Param{Ticket}->{TicketID},
             SLAID    => $Param{Config}->{SLAID},
             UserID   => $Param{UserID},
         );
 
         if ( !$Success ) {
-            $Self->{LogObject}->Log(
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'error',
                 Message  => $CommonMessage
                     . 'Ticket SLAID '
@@ -302,12 +204,12 @@ sub Run {
         )
     {
 
-        my $SLAID = $Self->{SLAObject}->SLALookup(
+        my $SLAID = $Kernel::OM->Get('Kernel::System::SLA')->SLALookup(
             Name => $Param{Config}->{SLA},
         );
 
         if ( !$SLAID ) {
-            $Self->{LogObject}->Log(
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'error',
                 Message  => $CommonMessage
                     . 'SLA '
@@ -324,7 +226,7 @@ sub Run {
         );
 
         if ( !$Success ) {
-            $Self->{LogObject}->Log(
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'error',
                 Message  => $CommonMessage
                     . 'SLA '
@@ -336,14 +238,14 @@ sub Run {
         }
 
         # set ticket SLA
-        $Success = $Self->{TicketObject}->TicketSLASet(
+        $Success = $Kernel::OM->Get('Kernel::System::Ticket')->TicketSLASet(
             TicketID => $Param{Ticket}->{TicketID},
             SLA      => $Param{Config}->{SLA},
             UserID   => $Param{UserID},
         );
 
         if ( !$Success ) {
-            $Self->{LogObject}->Log(
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'error',
                 Message  => $CommonMessage
                     . 'Ticket SLA '
@@ -354,7 +256,7 @@ sub Run {
         }
     }
     else {
-        $Self->{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'error',
             Message  => $CommonMessage
                 . "Couldn't update Ticket SLA - can't find valid SLA parameter!",
@@ -383,7 +285,7 @@ sub _CheckSLA {
     my ( $Self, %Param ) = @_;
 
     # get a list of assigned SLAs to the Service
-    my %SLAs = $Self->{SLAObject}->SLAList(
+    my %SLAs = $Kernel::OM->Get('Kernel::System::SLA')->SLAList(
         ServiceID => $Param{ServiceID},
         UserID    => 1,
     );
@@ -397,6 +299,7 @@ sub _CheckSLA {
     # otherwise return success
     return 1;
 }
+
 1;
 
 =back
