@@ -1,5 +1,5 @@
 # --
-# Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -13,6 +13,10 @@ use warnings;
 
 use base qw(Kernel::System::SupportDataCollector::PluginBase);
 
+our @ObjectDependencies = (
+    'Kernel::Config',
+);
+
 sub GetDisplayPath {
     return 'OTRS';
 }
@@ -20,8 +24,11 @@ sub GetDisplayPath {
 sub Run {
     my $Self = shift;
 
-    my $SOAPUser     = $Self->{ConfigObject}->Get('SOAP::User')     || '';
-    my $SOAPPassword = $Self->{ConfigObject}->Get('SOAP::Password') || '';
+    # get config object
+    my $ConfigObject = $Kernel::OM->Get('Kernel::Config');
+
+    my $SOAPUser     = $ConfigObject->Get('SOAP::User')     || '';
+    my $SOAPPassword = $ConfigObject->Get('SOAP::Password') || '';
 
     if ( $SOAPUser eq 'some_user' && ( $SOAPPassword eq 'some_pass' || $SOAPPassword eq '' ) ) {
         $Self->AddResultProblem(
