@@ -1,6 +1,5 @@
 // --
-// Core.Agent.Admin.ProcessManagement.js - provides the special module functions for the Process Management.
-// Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
+// Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
 // --
 // This software comes with ABSOLUTELY NO WARRANTY. For details, see
 // the enclosed file COPYING for license information (AGPL). If you
@@ -472,7 +471,7 @@ Core.Agent.Admin.ProcessManagement = (function (TargetNS) {
             }
         }
 
-        $('#Activities li, #ActivityDialogs li, #Transitions li, #TransitionActions li').draggable({
+        $('#Activities li.OneRow, #ActivityDialogs li.OneRow, #Transitions li.OneRow, #TransitionActions li.OneRow').draggable({
             revert: 'invalid',
             helper: function () {
                 var $Clone = $(this).clone();
@@ -523,7 +522,7 @@ Core.Agent.Admin.ProcessManagement = (function (TargetNS) {
         });
 
         $('#Canvas').droppable({
-            accept: '#Activities li, #ActivityDialogs li, #Transitions li, #TransitionActions li',
+            accept: '#Activities li.OneRow, #ActivityDialogs li.OneRow, #Transitions li.OneRow, #TransitionActions li.OneRow',
             drop: function (Event, UI) {
                 var $Source = $(UI.draggable),
                     SourceID = $Source.closest('ul').attr('id');
@@ -1256,9 +1255,9 @@ Core.Agent.Admin.ProcessManagement = (function (TargetNS) {
     TargetNS.HideOverlay = function () {
         $('#Overlay').remove();
         $('body').css({
-            'overflow': 'auto'
+            'overflow': 'visible',
+            'min-height': 0
         });
-        $('body').css('min-height', 'auto');
     };
 
     TargetNS.GetConditionConfig = function ($Conditions) {
@@ -1301,6 +1300,12 @@ Core.Agent.Admin.ProcessManagement = (function (TargetNS) {
             return false;
         }
 
+        // IE (11) has some permission problems with objects from other windows
+        // Therefore we "copy" the object if we are in IE
+        if ($.browser.trident) {
+            Config = Core.JSON.Parse(Core.JSON.Stringify(Config));
+        }
+
         // Update config from e.g. popup windows
 
         // Update Process
